.. yap documentation master file, created by
   sphinx-quickstart on Fri Sep 13 16:24:00 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

YAP documentation
===============================
Please read the new documentation of YAP here:

https://hq-1.gitbook.io/mc/

- Code: https://github.com/lhqing/cemba_data
- Author: Hanqing Liu, hanliu@salk.edu
